UiPath Documentation
automation-suite
2.2510
true
Guía de referencia de uipathctl
Importante :
Este contenido se ha localizado parcialmente a partir de un sistema de traducción automática. La localización de contenidos recién publicados puede tardar entre una y dos semanas en estar disponible.

Carga de Orchestrator de configuración de uipathctl

Carga archivos, extensiones NLog o complementos de almacén seguro al almacenamiento.

Descripción​

Cargue archivos, extensiones nlog o complementos de almacenamiento seguro en el almacenamiento

uipathctl config orchestrator upload [flags]
uipathctl config orchestrator upload [flags]

Ejemplos​

# Upload files to storage
uipathctl config orchestrator upload --storage-directory /path/to/storage/directory
# Upload nlog extensions to storage
uipathctl config orchestrator upload --nlog-extensions-directory /path/to/nlog/extensions/directory
# Upload secure store plugins to storage
uipathctl config orchestrator upload --securestore-plugins-directory /path/to/securestore/plugins/directory

# Upload files to external storage
uipathctl config orchestrator upload --storage-directory /path/to/storage/directory --is-external-storage
# Upload nlog extensions to external storage
uipathctl config orchestrator upload --nlog-extensions-directory /path/to/nlog/extensions/directory --is-external-storage
# Upload secure store plugins to external storage
uipathctl config orchestrator upload --securestore-plugins-directory /path/to/securestore/plugins/directory --is-external-storage
# Upload files to storage
uipathctl config orchestrator upload --storage-directory /path/to/storage/directory
# Upload nlog extensions to storage
uipathctl config orchestrator upload --nlog-extensions-directory /path/to/nlog/extensions/directory
# Upload secure store plugins to storage
uipathctl config orchestrator upload --securestore-plugins-directory /path/to/securestore/plugins/directory

# Upload files to external storage
uipathctl config orchestrator upload --storage-directory /path/to/storage/directory --is-external-storage
# Upload nlog extensions to external storage
uipathctl config orchestrator upload --nlog-extensions-directory /path/to/nlog/extensions/directory --is-external-storage
# Upload secure store plugins to external storage
uipathctl config orchestrator upload --securestore-plugins-directory /path/to/securestore/plugins/directory --is-external-storage

Opciones​

  -h, --help                                   help for upload
      --is-external-storage                    flag whether the storage is external
      --namespace string                       The namespace where UiPath Automation Suite is deployed (default "uipath")
      --nlog-extensions-directory string       location of the nlog extensions on the local disk
      --securestore-plugins-directory string   location of the securestore plugins on the local disk
      --storage-directory string               location of the storage directory on the local disk
  -h, --help                                   help for upload
      --is-external-storage                    flag whether the storage is external
      --namespace string                       The namespace where UiPath Automation Suite is deployed (default "uipath")
      --nlog-extensions-directory string       location of the nlog extensions on the local disk
      --securestore-plugins-directory string   location of the securestore plugins on the local disk
      --storage-directory string               location of the storage directory on the local disk

Opciones heredadas de los comandos principales​

      --context string      name of the kubeconfig context to use
  -f, --force               override all user prompts to true
      --kubeconfig string   kubectl configuration file (default: ~/.kube/config)
      --log-format string   log format. one of [text,json] (default "text")
      --log-level string    set log level. one of [trace,debug,info,error] (default "info")
  -q, --quiet               suppress all output except for errors and warnings
      --timeout duration    timeout of the command (default: 90 minutes) (default 1h30m0s)
      --versions string     optional path to versions file
      --context string      name of the kubeconfig context to use
  -f, --force               override all user prompts to true
      --kubeconfig string   kubectl configuration file (default: ~/.kube/config)
      --log-format string   log format. one of [text,json] (default "text")
      --log-level string    set log level. one of [trace,debug,info,error] (default "info")
  -q, --quiet               suppress all output except for errors and warnings
      --timeout duration    timeout of the command (default: 90 minutes) (default 1h30m0s)
      --versions string     optional path to versions file
  • Descripción​
  • Ejemplos​
  • Opciones​
  • Opciones heredadas de los comandos principales​

¿Te ha resultado útil esta página?

Conectar

¿Necesita ayuda? Soporte

¿Quiere aprender? UiPath Academy

¿Tiene alguna pregunta? Foro de UiPath

Manténgase actualizado